<?php
/*==NukeEvent Portal System=====================================================
Copyright 2002 by Christian Berg

Code based on PHP-NUKE Web Portal System Copyright (c) 2002 by
Francisco Burzi (fbc@mandrakesoft.com) http://phpnuke.org

This program is free software. You can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 or any higher Version
of the License.
==============================================================================*/

/**
* This is the legenedary 'Main-File. This file provides some neat functions
* common used by the most modules.
*
* @package nukeevent
* @author $Author: x-eniac $
* @version $Revision: 1.4 $
*/

/**
*
*/
function neErrorHandler ($intErrorType, $strErrorMessage, $strFilename, $intLinenum, $arrVars) {
    global $neConfig, $neErrors;
    $neErrors[] = array(
        'type' => $intErrorType,
        'message' => $strErrorMessage,
        'file' => basename($strFilename),
        'line' => $intLinenum,
    );
    // timestamp for the error entry
    $strErrorTime = date("Y-m-d H:i:s (T)");
    if ($neConfig['debug']['error_log'] == true) {
        error_log($strErrorMessage);
    }

    if ($neConfig['debug']['mail_error'] == true) {
        mail($neConfig['notify']['to'],"[NE_ERROR:$intErrorNo] $strErrorMessage",$strErrorMessage);
    }
}


/**
* Translates Strings to the user set Language
*
* This function simply reads an very big Array.
* It searches for an Arrayelement called like the parameter it becomes
* If there is such an element it returns the Translation, else it returns
* a Message that pleases to user to do this.
*
* @param string the Phrase that should be translated
* @param boolean if set to true the translation of this Phrase is optional
* @global $neTranslate
* @return string the Translated String
*/
function neTranslate($strPhrase, $bolTranslateOpotional = false) {
	global $neTranslate;
	if (is_array($strPhrase)) {
		$strPhrase = $strPhrase['0'];
	}
	if (isset($neTranslate[$strPhrase])) {
		return $neTranslate[$strPhrase];
	} else {
		if ($bolTranslateOpotional == true) {
			return $strPhrase;
		} else {
			return '[Translate: '.$strPhrase.']';
		}
	}
}

/**
* loads the languagepack for the Usercoosen Language.
*
* @param string The Name of the Module for which the Languagepack should be
*        loaded.
* @return boolean 'true' if the langfile could be loaded, 'false' if not so.
*/
function neGetLang($strModulename) {
	global $neSession, $neTranslate;
	$strLangfile = 'lang-'.$neSession -> getLang().'.inc.php';
	$neTranslate_old = $neTranslate;
	if ($strModulename == 'nukeevent' and file_exists('includes/language/'.$strLangfile)) {
		$strLangfile = 'includes/language/'.$strLangfile;
	}
	elseif (file_exists('modules/'.$strModulename.'/language/'.$strLangfile)) {
		$strLangfile = 'modules/'.$strModulename.'/language/'.$strLangfile;
	} else {
		return false;
	}
	include_once ($strLangfile);
	$neTranslate = array_merge($neTranslate_old, $neTranslate);
	unset($neTranslate_old);
	return true;
}

/**
* Redirects to a Site. Also Prints a themed please Wait vou will be redirected Message.
*/
function neRedirect($strUrl) {
	global $neConfig, $neTheme;
	header("Location: ".$neConfig['site']['url'].'/'.$strUrl);
	$neTheme -> drawRedirectPage($strUrl);
}

/**
 * Check a Databaseresult on Errors.
 * Checks if a result returned an Error.
 * If true an Errorpage is drawn, else the function returns 'true'
 *
 * @param object a Resultobject from the PearDB Class
 * @param integer the Line of the command.
 * @param string the Name of the File the Error occours.
 * @param string the SQL Query string.
 * @return boolean
 */
function neGetDbError($result, $line, $file, $query = "") {
	if (DB::isError($result)) {
        global $neTheme, $neModuleName, $neSession, $neConfig;
        $strErrormessage = '<p>'.neTranslate(DB :: errorMessage($result), true).'</p>';
        if ( $neSession->isAdmin($neModuleName) ) {
    	    $strErrormessage .= '<b>'.neTranslate('query').':</b><p><tt>'.$query.'</tt></p>';
        }
        if ( $neConfig['debug']['enabled'] == true ) {
            $strErrormessage .= '<p>';
    		$strErrormessage .= neTranslate('near_line').': <b>'.$line.'</b><br/>';
    		$strErrormessage .= neTranslate('in_module').': <b>'.$neModuleName.'</b><br/>';
    		$strErrormessage .= neTranslate('in_file').': <b>'.basename($file).'</b><br/>';
    		$strErrormessage .= '</p>';
    		$strErrormessage .= '<tt>';
    		$strErrormessage .= $result->getDebugInfo();
    		$strErrormessage .= '</tt>';
    	}
		$neTheme->drawErrorpage($result->getMessage(),$strErrormessage);       
	} else {
		return true;
	}
}

/**
 * Show a quick and dirty Errormessage.
 * @param string the error .
 * @return boolean
 */
function neDrawError($strError) {
	global $neTheme;
		$neTheme ->drawErrorpage(
		    neTranslate($strError),
		    neTranslate('text-'.$strError)
		);
}

/**
* Formats an Timestamp in a localised timestring.
* @param mixed a Timestamp or a RFC Formatted Datestring to Format
* @param string the format for the output
* date = only the date
* time = only the time
* datetime = Date and Time
* @return string the formatted date and/or time
*/
function neFormatTimestamp($timestamp, $format='date') 
{
	if (is_string($timestamp)) {
		$timestamp = strtotime($timestamp);
	}
	switch (strtolower($format)) {
		case 'time':
			$timestamp = strftime(neTranslate('timeformat'), $timestamp);
			break;
		case 'datetime':
			$timestamp = strftime(neTranslate('datetimestring'), $timestamp);
			break;
        default:
		case 'date':			
		    $timestamp = strftime(neTranslate('dateformat'), $timestamp);
			break;
	}
	return ($timestamp);
}

/**
* Encodes the UBB String in HTML.
* Removes all html tags and exchanges only the ubb tags and with html tags.
*
* @access    public
* @param     String      The String that should be encoded
* @return    String
*/
function neEncodeUbb($strText) {
	include_once('HTML/BBCodeParser.php');
	$parser = new HTML_BBCodeParser();
    $parser->setText($strText);
    $parser->parse();
    return $parser->getParsed();
}

/**
* Checks the String from the Input and removes unallowed HTML.
* This is a good Method to Transform the HTML for Output.
* If you want to transform the Text within an inputfield use
* neTransformInput intead.
*/
function neCheckText($strText, $strMode = 'plain') {
    global $neConfig, $neSession, $neTheme;
    $strText = trim(stripcslashes($strText));
    if (@eregi("<[^>]*script*\"\\?/[^>]*>", $strText)) {
      $neTheme->drawErrorpage(neTranslate('illegal_javascript'),neTranslate('text-illegal_javascript'));
    }
    switch (strtolower($strMode)) {
      case 'html':
        if ($neSession -> isAdmin()) {
            $strText = strip_tags($strText, $neConfig['allowedhtml']['admin']);
        } else {
            $strText = strip_tags($strText, $neConfig['allowedhtml']['user']);
        }
        break;
      case 'ubb':
        $strText = strip_tags($strText);
        break;
      default:
        $strText = htmlentities($strText);
        break;
    }
    return $strText;
}

/**
* Checks for Words and Cesor them
*/
function neCheckWords($strMessage) {
	global $neConfig;
	return $strMessage;
}

/**
* Makes both a Censor Modue and a HTML Filter
*/
function neFilterText($strMessage, $strMode = '') {
	$strMessage = neCheckWords($strMessage);
	$strMessage = neCheckText($strMessage, $strMode);
	return $strMessage;
}

/**
* Gets the Username from cached Array
* @param integer The userId.
* @returns string The users name.
*/

function neGetUserName($intUserId) {
	global $neConfig, $neDb;
	static $arrUsers;
	//Get a Array with all Users from the Database and Cache it!
	if (!is_array($arrUsers)) {
		$result = $neDb -> query('
		            SELECT uid, username
		            FROM '.$neConfig['db']['userprefix'].'_users
		        ');
		neGetDbError($result, __LINE__, __FILE__);
		while (list ($id, $name) = $result -> fetchRow()) {
			$arrUsers[$id] = $name;
		}
	}
	if (array_key_exists($intUserId, $arrUsers)) {
		return $arrUsers[$intUserId];
	} else {
		return $neConfig['default']['username'];
	}
}

/**
* resizes an Image.
*/
function neResizeImage($inputfile, $outputfile, $sizex, $sizey) {
	global $neConfig;
	if ( !$tmp = getimagesize($inputfile) ) {
		return false;
	}
	
	switch ($neConfig['image']['resize_method']) {
		case 'imagemagik' :
			exec($neConfig['image']['imagemagik_path'].' -size '.$sizex.'x'.$sizey.' '.$inputfile.' -resize '.$sizex.'x'.$sizey.' +profile "x" '.$outputfile);
			break;
		case 'gdlib' :
			break;
	}
	if ( file_exists($outputfile) ) {
	    return true;
	} else {
		return false;
	}
}
?>
